@@ -1,7 +1,6 @@
-use serde::{Deserialize, Serialize};
-
 use crate::dtos::{CalendarDTO, EventWithInstancesDTO};
 use nettu_scheduler_domain::{Calendar, EventInstance, ID};
+use serde::{Deserialize, Serialize};
 
 #[derive(Deserialize, Serialize)]
 #[serde(rename_all = "camelCase")]
@@ -246,7 +245,7 @@ pub mod get_user_freebusy {
         pub calendar_ids: Option<String>,
     }
 
-    #[derive(Debug, Serialize)]
+    #[derive(Debug, Serialize, Deserialize)]
     #[serde(rename_all = "camelCase")]
     pub struct APIResponse {
         pub busy: VecDeque<EventInstance>,
