@@ -1,10 +1,9 @@
+use crate::dtos::{ServiceDTO, ServiceResourceDTO, ServiceWithUsersDTO};
 use nettu_scheduler_domain::{
     BusyCalendar, Service, ServiceResource, ServiceWithUsers, TimePlan, ID,
 };
 use serde::{Deserialize, Serialize};
 
-use crate::dtos::{ServiceDTO, ServiceResourceDTO, ServiceWithUsersDTO};
-
 #[derive(Deserialize, Serialize)]
 #[serde(rename_all = "camelCase")]
 pub struct ServiceResponse {
@@ -127,8 +126,8 @@ pub mod remove_service_event_intend {
         message: String,
     }
 
-    impl APIResponse {
-        pub fn new() -> Self {
+    impl Default for APIResponse {
+        fn default() -> Self {
             Self {
                 message: "Deleted Booking Intend".into(),
             }
